import { FileInfo, SupportedFiles } from './interfaces/files.interface';
import { RemoteBundle, ConnectionOptions } from './http';
import { AnalyzeFoldersOptions } from './interfaces/analysis-options.interface';
interface PrepareRemoteBundleOptions extends ConnectionOptions {
    files: FileInfo[];
    bundleHash?: string;
    removedFiles?: string[];
}
interface UpdateRemoteBundleOptions extends ConnectionOptions {
    bundleHash: string;
    files: FileInfo[];
}
/**
 * Splits files in buckets and upload in parallel
 * @param baseURL
 * @param sessionToken
 * @param remoteBundle
 */
export declare function uploadRemoteBundle(options: UpdateRemoteBundleOptions): Promise<void>;
interface RemoteBundleFactoryOptions extends PrepareRemoteBundleOptions {
    baseDir: string;
}
export declare function remoteBundleFactory(options: RemoteBundleFactoryOptions): Promise<RemoteBundle | null>;
/**
 * Get supported filters and test baseURL for correctness and availability
 *
 * @param baseURL
 * @param source
 * @returns
 */
export declare function getSupportedFiles(baseURL: string, source: string, requestId?: string, languages?: string[], orgId?: string, extraHeaders?: Record<string, string>): Promise<SupportedFiles>;
export interface FileBundle extends RemoteBundle {
    baseDir: string;
    supportedFiles: SupportedFiles;
    fileIgnores: string[];
    skippedOversizedFiles?: string[];
}
export interface CreateBundleFromFoldersOptions extends ConnectionOptions, AnalyzeFoldersOptions {
}
/**
 * Creates a remote bundle and returns response from the bundle API
 *
 * @param {CreateBundleFromFoldersOptions} options
 * @returns {Promise<FileBundle | null>}
 */
export declare function createBundleFromFolders(options: CreateBundleFromFoldersOptions): Promise<FileBundle | null>;
/**
 * Creates a remote bundle and returns response from the bundle API
 * This function is used to create a bundle with a custom list of supported file extensions
 *
 * @param {CreateBundleFromFoldersOptions} options
 * @param {SupportedFiles} supportedFiles
 * @returns {Promise<FileBundle | null>}
 */
export declare function createBundleWithCustomFiles(options: CreateBundleFromFoldersOptions, supportedFiles: SupportedFiles): Promise<FileBundle | null>;
export {};
