import { Cache } from './cache';
import { CollectBundleFilesOptions, FilePolicies } from './interfaces/analysis-options.interface';
import { SupportedFiles, FileInfo } from './interfaces/files.interface';
export declare function notEmpty<T>(value: T | null | undefined): value is T;
export declare function parseFileIgnores(path: string): string[];
export declare function getGlobPatterns(supportedFiles: SupportedFiles): string[];
/**
 * Recursively collect all exclude and ignore rules from "dirs".
 *
 * Exclude rules from .snyk files and ignore rules from .[*]ignore files are collected separately.
 * Any .[*]ignore files in paths excluded by .snyk exclude rules are ignored.
 */
export declare function collectFilePolicies(dirs: string[], symlinksEnabled?: boolean, fileIgnores?: string[]): Promise<FilePolicies>;
export declare function determineBaseDir(paths: string[]): string;
/**
 * Returns bundle files from requested paths
 * If a file exceeds the maximum file size, it returns a string with its path
 * */
export declare function collectBundleFiles({ symlinksEnabled, baseDir, filePolicies, paths, supportedFiles, }: CollectBundleFilesOptions): AsyncGenerator<FileInfo | string>;
export declare function prepareExtendingBundle(baseDir: string, supportedFiles: SupportedFiles, fileIgnores: string[] | undefined, files: string[], symlinksEnabled?: boolean): Promise<{
    files: FileInfo[];
    removedFiles: string[];
}>;
export declare function getBundleFilePath(filePath: string, baseDir: string): string;
export declare function calcHash(content: string): string;
export declare function getFileInfo(filePath: string, baseDir: string, withContent?: boolean, cache?: Cache | null): Promise<FileInfo | null>;
export declare function resolveBundleFiles(baseDir: string, bundleMissingFiles: string[]): Promise<FileInfo[]>;
export declare function resolveBundleFilePath(baseDir: string, bundleFilePath: string): string;
export declare function composeFilePayloads(files: FileInfo[], bucketSize?: number): Generator<FileInfo[]>;
export declare function isMatch(filePath: string, rules: string[]): boolean;
